@@ -486,6 +486,9 @@ class LumeProvider(BaseVMProvider):
         """Update VM configuration."""
         return self._lume_api_update(name, update_opts, debug=self.verbose)
         
+    async def restart_vm(self, name: str, storage: Optional[str] = None) -> Dict[str, Any]:
+        raise NotImplementedError("LumeProvider does not support restarting VMs.")
+        
     async def get_ip(self, name: str, storage: Optional[str] = None, retry_delay: int = 2) -> str:
         """Get the IP address of a VM, waiting indefinitely until it's available.
         
